@@ -2307,21 +2307,15 @@ ebews_start_sync (gpointer data)
 	{
 		GSList *items_created = NULL, *items_updated = NULL;
 		GSList *items_deleted = NULL;
-		gchar *old_sync_state = sync_state;
-
-		sync_state = NULL;
 
 		e_ews_connection_sync_folder_items_sync (
 			priv->cnc, EWS_PRIORITY_MEDIUM,
-			old_sync_state, priv->folder_id,
-			"IdOnly", NULL, EWS_MAX_FETCH_COUNT,
-			&sync_state,
-			&includes_last_item,
+			&sync_state, priv->folder_id,
+			"IdOnly", NULL,
+			EWS_MAX_FETCH_COUNT, &includes_last_item,
 			&items_created, &items_updated,
 			&items_deleted, priv->cancellable, &error);
 
-		g_free (old_sync_state);
-
 		if (error)
 			break;
 
@@ -2459,7 +2453,7 @@ fetch_from_offline (EBookBackendEws *ews,
 
 	if (priv->is_gal && !g_strcmp0 (query, "(contains \"x-evolution-any-field\" \"\")")) {
 		e_data_book_view_notify_complete (book_view, error);
-		e_data_book_view_unref (book_view);
+		g_object_unref (book_view);
 		return;
 	}
 
@@ -2479,15 +2473,16 @@ fetch_from_offline (EBookBackendEws *ews,
 	if (contacts)
 		g_slist_free (contacts);
 	e_data_book_view_notify_complete (book_view, error);
-	e_data_book_view_unref (book_view);
+	g_object_unref (book_view);
 }
 
 static void
-e_book_backend_ews_start_book_view (EBookBackend *backend,
-                                    EDataBookView *book_view)
+e_book_backend_ews_start_view (EBookBackend *backend,
+                               EDataBookView *book_view)
 {
 	EBookBackendEws *ebews;
 	EBookBackendEwsPrivate *priv;
+	EBookBackendSExp *sexp;
 	const gchar *query;
 	gboolean is_autocompletion = FALSE;
 	gchar *auto_comp_str = NULL;
@@ -2502,11 +2497,13 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 
 	ebews = E_BOOK_BACKEND_EWS (backend);
 	priv = ebews->priv;
-	query = e_data_book_view_get_card_query (book_view);
+
+	sexp = e_data_book_view_get_sexp (book_view);
+	query = e_book_backend_sexp_text (sexp);
 
 	source = e_backend_get_source (E_BACKEND (backend));
 
-	e_data_book_view_ref (book_view);
+	g_object_ref (book_view);
 	e_data_book_view_notify_progress (book_view, -1, _("Searching..."));
 
 	if (!e_backend_get_online (E_BACKEND (backend))) {
@@ -2517,13 +2514,13 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 
 		error = EDB_ERROR (OFFLINE_UNAVAILABLE);
 		e_data_book_view_notify_complete (book_view, error);
-		e_data_book_view_unref (book_view);
+		g_object_unref (book_view);
 		g_error_free (error);
 		return;
 	}
 
 	if (priv->cnc == NULL) {
-		/* XXX Why doesn't start_book_view()
+		/* XXX Why doesn't start_view()
 		 *     get passed a GCancellable? */
 		e_backend_authenticate_sync (
 			E_BACKEND (backend),
@@ -2531,7 +2528,7 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 			NULL, &error);
 		if (error != NULL) {
 			e_data_book_view_notify_complete (book_view, error);
-			e_data_book_view_unref (book_view);
+			g_object_unref (book_view);
 			g_error_free (error);
 			return;
 		}
@@ -2551,7 +2548,7 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 	if (!is_autocompletion || !auto_comp_str) {
 		g_free (auto_comp_str);
 		e_data_book_view_notify_complete (book_view, error);
-		e_data_book_view_unref (book_view);
+		g_object_unref (book_view);
 		return;
 	}
 
@@ -2581,7 +2578,7 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 	e_ews_folder_id_free (fid);
 	if (error != NULL) {
 		e_data_book_view_notify_complete (book_view, error);
-		e_data_book_view_unref (book_view);
+		g_object_unref (book_view);
 		g_clear_error (&error);
 		return;
 	}
@@ -2630,12 +2627,12 @@ e_book_backend_ews_start_book_view (EBookBackend *backend,
 	g_slist_free (mailboxes);
 	g_slist_free (contacts);
 	e_data_book_view_notify_complete (book_view, error);
-	e_data_book_view_unref (book_view);
+	g_object_unref (book_view);
 }
 
 static void
-e_book_backend_ews_stop_book_view (EBookBackend *backend,
-                                   EDataBookView *book_view)
+e_book_backend_ews_stop_view (EBookBackend *backend,
+                              EDataBookView *book_view)
 {
 	EBookBackendEws *bews = E_BOOK_BACKEND_EWS (backend);
 	EBookBackendEwsPrivate *priv = bews->priv;
@@ -2829,15 +2826,16 @@ e_book_backend_ews_open (EBookBackend *backend,
 		gboolean need_to_authenticate;
 
 		PRIV_LOCK (cbews->priv);
-		need_to_authenticate = cbews->priv->cnc == NULL && e_backend_get_online (E_BACKEND (backend));
+		need_to_authenticate =
+			(cbews->priv->cnc == NULL) &&
+			(e_backend_get_online (E_BACKEND (backend)));
 		PRIV_UNLOCK (cbews->priv);
 
-		if (need_to_authenticate) {
+		if (need_to_authenticate)
 			e_backend_authenticate_sync (
 				E_BACKEND (backend),
 				E_SOURCE_AUTHENTICATOR (backend),
 				cancellable, &error);
-		}
 	}
 
 	convert_error_to_edb_error (&error);
@@ -2957,18 +2955,10 @@ book_backend_ews_try_password_sync (ESourceAuthenticator *authenticator,
 		if (backend->priv->cnc != NULL)
 			g_object_unref (backend->priv->cnc);
 		backend->priv->cnc = g_object_ref (connection);
-		backend->priv->is_writable = !backend->priv->is_gal;
 
 		PRIV_UNLOCK (backend->priv);
-
-		e_book_backend_notify_online (E_BOOK_BACKEND (backend), TRUE);
-	} else {
-		backend->priv->is_writable = FALSE;
-		e_book_backend_notify_online (E_BOOK_BACKEND (backend), FALSE);
 	}
 
-	e_book_backend_notify_readonly (E_BOOK_BACKEND (backend), !backend->priv->is_writable);
-
 	g_object_unref (connection);
 
 	g_free (hosturl);
@@ -2994,8 +2984,8 @@ e_book_backend_ews_class_init (EBookBackendEwsClass *klass)
 	parent_class->modify_contacts         = e_book_backend_ews_modify_contacts;
 	parent_class->get_contact             = e_book_backend_ews_get_contact;
 	parent_class->get_contact_list        = e_book_backend_ews_get_contact_list;
-	parent_class->start_book_view         = e_book_backend_ews_start_book_view;
-	parent_class->stop_book_view          = e_book_backend_ews_stop_book_view;
+	parent_class->start_view              = e_book_backend_ews_start_view;
+	parent_class->stop_view               = e_book_backend_ews_stop_view;
 
 	object_class->dispose                 = e_book_backend_ews_dispose;
 }
