@@ -45,8 +45,7 @@ delete_folder_cb (GObject *object,
 	EEwsConnection *cnc = E_EWS_CONNECTION (object);
 	GError *error = NULL;
 
-	e_ews_connection_delete_folder_finish	(cnc, res,
-						 &error);
+	e_ews_connection_delete_folder_finish (cnc, res, &error);
 	if (error != NULL) {
 		g_warning ("Unable to create: %s \n", error->message);
 		g_clear_error (&error);
@@ -67,6 +66,7 @@ op_test_delete_folder (gpointer data)
 	const gchar *uri;
 	EEwsConnection *cnc;
 	GCancellable *cancellable;
+	CamelEwsSettings *settings;
 	EwsFolderId **fid = (EwsFolderId **) data;
 
 	cancellable = g_cancellable_new ();
@@ -76,8 +76,15 @@ op_test_delete_folder (gpointer data)
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, 30, NULL, NULL, NULL);
-	g_assert (cnc != NULL);
+	settings = g_object_new (
+		CAMEL_TYPE_EWS_SETTINGS,
+		"user", username, NULL);
+
+	cnc = e_ews_connection_new (uri, settings);
+	e_ews_connection_set_password (cnc, password);
+
+	g_object_unref (settings);
+
 	e_ews_connection_delete_folder (
 		cnc, EWS_PRIORITY_MEDIUM, (*fid)->id,
 		FALSE ,"HardDelete", cancellable,
